==> eiffelstudio-18.07.10.1981.tar: F_code/C14/ev677.c <==
/*
 * Code for class EV_HORIZONTAL_SEPARATOR_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev677.h"
#include <ev_gtk.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_HORIZONTAL_SEPARATOR_IMP}.make */
void F1312_12399 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER loc1 = (EIF_POINTER) 0;
	EIF_POINTER tp1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("make", 1311, Current, 1, 0, 18301);
	RTGC;
	RTHOOK(1);
	tp1 = (EIF_POINTER) gtk_event_box_new();
	F1193_10899(Current, tp1);
	RTHOOK(2);
	loc1 = (EIF_POINTER) gtk_hseparator_new();
	RTHOOK(3);
	gtk_widget_show((GtkWidget*) loc1);
	RTHOOK(4);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_40_11_10_2_0_0_);
	gtk_container_add((GtkContainer*) tp1, (GtkWidget*) loc1);
	RTHOOK(5);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_40_11_10_2_0_0_);
	gtk_widget_set_usize((GtkWidget*) tp1, (gint) ((EIF_INTEGER_32) -1L), (gint) ((EIF_INTEGER_32) 1L));
	RTHOOK(6);
	F1300_12149(Current);
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {EV_HORIZONTAL_SEPARATOR_IMP}.interface */
static EIF_REFERENCE F1312_12400_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("interface", 1311, Current, 0, 0, 18299);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F1312_12400 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_23_);
	if (!r) {
		if (RTAT(eif_final_id(Y8197,Y8197_gen_type,Dftype(Current),1166))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F1312_12400_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_23_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


void EIF_Minit677 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C14/ev677.c <==
/*
 * Code for class EV_VERTICAL_SEPARATOR_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev677.h"
#include <ev_gtk.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_VERTICAL_SEPARATOR_IMP}.make */
void F1315_12459 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER loc1 = (EIF_POINTER) 0;
	EIF_POINTER tp1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("make", 1314, Current, 1, 0, 18395);
	RTGC;
	RTHOOK(1);
	tp1 = (EIF_POINTER) gtk_event_box_new();
	F1197_10962(Current, tp1);
	RTHOOK(2);
	loc1 = (EIF_POINTER) gtk_vseparator_new();
	RTHOOK(3);
	gtk_widget_show((GtkWidget*) loc1);
	RTHOOK(4);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_40_11_10_2_0_0_);
	gtk_container_add((GtkContainer*) tp1, (GtkWidget*) loc1);
	RTHOOK(5);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_40_11_10_2_0_0_);
	gtk_widget_set_usize((GtkWidget*) tp1, (gint) ((EIF_INTEGER_32) 1L), (gint) ((EIF_INTEGER_32) -1L));
	RTHOOK(6);
	F1304_12212(Current);
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {EV_VERTICAL_SEPARATOR_IMP}.interface */
static EIF_REFERENCE F1315_12460_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("interface", 1314, Current, 0, 0, 18396);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F1315_12460 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_23_);
	if (!r) {
		if (RTAT(eif_final_id(Y8237,Y8237_gen_type,Dftype(Current),1170))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F1315_12460_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_23_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


void EIF_Minit677 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
